package com.macys.exception;

import javax.ws.rs.core.Response;
import javax.ws.rs.core.Response.Status;
import javax.ws.rs.ext.ExceptionMapper;
import javax.ws.rs.ext.Provider;

import org.apache.commons.lang.exception.ExceptionUtils;

import com.macys.exception.ErrorCodes;
import com.macys.exception.ServiceException;
import com.macys.exception.v1.ServiceErrorDataV1;

@Provider
public class RestServiceExceptionHandler implements ExceptionMapper<ServiceException> {

    @Override
    public Response toResponse(ServiceException se) {
    	
    	// Use the v1 so it have the xmlrootelement annotation necessary to marshal
    	ServiceErrorDataV1 serviceErrorDataV1 = new ServiceErrorDataV1(se.data.code, se.data.title, se.data.description, ExceptionUtils.getStackTrace(se));
    	
    	// map the service exception code value to the http status code
    	javax.ws.rs.core.Response.Status status = Status.INTERNAL_SERVER_ERROR;
    	
    	if (se.data.code == ErrorCodes.UNKNOWN.getCode())
    		status = Status.INTERNAL_SERVER_ERROR;
    	else if (se.data.code == ErrorCodes.OK.getCode())
    		status = Status.OK;
    	else if (se.data.code == ErrorCodes.PARAMETER.getCode())
    		status = Status.BAD_REQUEST;
    	else if (se.data.code == ErrorCodes.MARSHALL.getCode())
    		status = Status.INTERNAL_SERVER_ERROR;
    	else if (se.data.code == ErrorCodes.UNKNOWN_REQUEST.getCode())
    		status = Status.BAD_REQUEST;
    	else if (se.data.code == ErrorCodes.SMARTQ.getCode())
    		status = Status.INTERNAL_SERVER_ERROR;
    	else if (se.data.code == ErrorCodes.ISP_UNAVAILABLE.getCode())
    		status = Status.SERVICE_UNAVAILABLE;
    	else if (se.data.code == ErrorCodes.BAD_DATA.getCode())
    		status = Status.BAD_REQUEST;
    	else if (se.data.code == ErrorCodes.HOST_SYSTEM_ERROR.getCode())
    		status = Status.SERVICE_UNAVAILABLE;
    	else if (se.data.code == ErrorCodes.TIMEOUT.getCode())
    		status = Status.SERVICE_UNAVAILABLE;
    	else if (se.data.code == ErrorCodes.ENCRYPTION.getCode())
    		status = Status.BAD_REQUEST;
    	else if (se.data.code == ErrorCodes.DECRYPTION.getCode())
    		status = Status.BAD_REQUEST;
    	else if (se.data.code == ErrorCodes.DATABASE.getCode())
    		status = Status.SERVICE_UNAVAILABLE;
    		
        return Response.status(status).entity(serviceErrorDataV1).build();  
    }
}
